@@ -51,6 +51,9 @@
 #if HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #if HAVE_SYS_SOCKETVAR_H
+#if dynix
+#include <sys/param.h>
+#endif
 #include <sys/socketvar.h>
 #endif
 #elif HAVE_WINSOCK_H
@@ -165,9 +168,10 @@ void snmpd_set_agent_address(const char *token, char *cptr)
 
     if (ptr)
 	/* append to the older specification string */
-	sprintf(buf,"%s,%s", ptr, cptr);
+	snprintf(buf, sizeof(buf), "%s,%s", ptr, cptr);
     else
-	strcpy(buf,cptr);
+	strncpy(buf, cptr, sizeof(buf));
+    buf[sizeof(buf)-1] = '\0';
 
     DEBUGMSGTL(("snmpd_ports","port spec: %s\n", buf));
     ds_set_string(DS_APPLICATION_ID, DS_AGENT_PORTS, strdup(buf));
