@@ -1461,8 +1461,9 @@ Interface_Scan_Init (void)
                 snmp_log(LOG_ERR,"/proc/net/dev data format error, line ==|%s|",line);
         }
 
-        *stats++ = 0;
+        *stats   = 0;
         strcpy(ifname_buf, ifstart);
+        *stats++ = ':';
         while (*stats == ' ') stats++;
 
         if ((scan_line_to_use == scan_line_2_2 &&
@@ -1569,6 +1570,10 @@ Interface_Scan_Init (void)
 #ifdef ARPHRD_HIPPI
 	  case ARPHRD_HIPPI:
 	      nnew->if_type = 47; break;
+#endif
+#ifdef ARPHRD_ATM
+	  case ARPHRD_ATM:
+	      nnew->if_type = 37; break;
 #endif
           /* XXX: more if_arp.h:ARPHDR_xxx to IANAifType mappings... */
 	  }
