@@ -357,13 +357,44 @@ SnmpdDump(int a)
 #endif
 
 
-	static void
+static void
 SnmpTrapNodeDown(void)
 {
     send_easy_trap (SNMP_TRAP_ENTERPRISESPECIFIC, 2);
     /* XXX  2 - Node Down #define it as NODE_DOWN_TRAP */
 }
 
+static void
+setup_log(int restart, int dont_zero, int stderr_log, int syslog_log, 
+	  char *logfile)
+{
+    static char logfile_s[PATH_MAX + 1] = { 0 };
+    static int dont_zero_s  = 0;
+    static int stderr_log_s = 0;
+    static int syslog_log_s = 0;
+
+    if (restart == 0) {
+	if (logfile != NULL) {
+	    strncpy(logfile_s, logfile, PATH_MAX);
+	}
+	dont_zero_s  = dont_zero;
+	stderr_log_s = stderr_log;
+	syslog_log_s = syslog_log;
+    }
+
+    if (!stderr_log_s) {
+	snmp_disable_stderrlog();
+    }
+
+    if (logfile_s[0]) {
+	snmp_enable_filelog(logfile_s, dont_zero_s);
+    }
+
+    if (syslog_log_s) {
+	snmp_enable_syslog();
+    }
+}
+
 /*******************************************************************-o-******
  * main - Non Windows
  * SnmpDeamonMain - Windows to support windows serivce
@@ -628,6 +659,8 @@ main(int argc, char *argv[])
 	    }
 	}  /* end-for */
 
+	setup_log(0, dont_zero_log, stderr_log, syslog_log, logfile);
+
 	/* 
 	 * Initialize a argv set to the current for restarting the agent.
 	 */
@@ -656,15 +689,6 @@ main(int argc, char *argv[])
 	*cptr = 0;
 	*argvptr = NULL;
 
-	/* 
-	 * Open the logfile if necessary.
-	 */
-
-	/* Should open logfile and/or syslog based on arguments */
-	if (logfile[0])
-		snmp_enable_filelog(logfile, dont_zero_log);
-	if (syslog_log)
-		snmp_enable_syslog(); 
 #ifdef BUFSIZ
 	setvbuf(stdout, NULL, _IOLBF, BUFSIZ);
 #endif
@@ -678,11 +702,6 @@ main(int argc, char *argv[])
     }
 #endif
 
-    /*  Honor selection of standard error output.  */
-    if (!stderr_log) {
-      snmp_disable_stderrlog();
-    }
-
 #if defined(SIGPIPE) && defined(SIG_IGN)
     signal(SIGPIPE, SIG_IGN);  /* 'Inline' failure of wayward readers */
 #endif
@@ -832,6 +851,11 @@ receive(void)
         if (reconfig) {
 	    reconfig = 0;
 	    snmp_log(LOG_INFO, "Reconfiguring daemon\n");
+	    /*  Stop and restart logging.  This allows logfiles to be
+		rotated etc.  */
+	    snmp_disable_log();
+	    setup_log(1, 0, 0, 0, NULL);
+	    snmp_log(LOG_INFO, "UCD-SNMP version %s restarted\n", VersionInfo);
 	    update_config();
         }
 
