@@ -247,8 +247,8 @@ int main(int argc, char *argv[])
 	      if (check && snmp_oid_compare(name, name_length, vars->name,
 	      				    vars->name_length) >= 0) {
 		char name_buf[SPRINT_MAX_LEN], var_buf[SPRINT_MAX_LEN];
-		sprint_objid(name_buf, name, name_length);
-		sprint_objid(var_buf, vars->name, vars->name_length);
+		snprint_objid(name_buf, sizeof(name_buf), name, name_length);
+		snprint_objid(var_buf, sizeof(var_buf), vars->name, vars->name_length);
 		fprintf(stderr, "Error: OID not increasing: %s >= %s\n",
 			name_buf, var_buf);
 	        running = 0;
@@ -277,7 +277,8 @@ int main(int argc, char *argv[])
                 /*EMPTY*/;
               if (vars)
                 fprint_objid(stderr, vars->name, vars->name_length);
-              fprintf(stderr, "\n");
+	      else
+		fprintf(stderr, "\n");
             }
 	    exitval = 2;
           }
